"""added bid_ask_sum

Revision ID: c5800ee0c7ab
Revises: 77203ed2c699
Create Date: 2024-07-15 15:37:11.347976

"""

import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = "c5800ee0c7ab"
down_revision = "77203ed2c699"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    exchange_enum = postgresql.ENUM(name="exchange", schema="public", create_type=False)
    op.create_table(
        "bid_ask_sum",
        sa.Column("bids_sum_5", sa.Float(), nullable=False),
        sa.Column("bids_sum_10", sa.Float(), nullable=False),
        sa.Column("bids_sum_15", sa.Float(), nullable=False),
        sa.Column("bids_sum_20", sa.Float(), nullable=False),
        sa.Column("asks_sum_5", sa.Float(), nullable=False),
        sa.Column("asks_sum_10", sa.Float(), nullable=False),
        sa.Column("asks_sum_15", sa.Float(), nullable=False),
        sa.Column("asks_sum_20", sa.Float(), nullable=False),
        sa.Column("exchange", exchange_enum, nullable=False),
        sa.Column("symbol", sa.String(), nullable=False),
        sa.Column("timestamp", sa.BIGINT(), nullable=False),
        sa.Column("datetime", sa.DateTime(), nullable=False),
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("created_at", sa.TIMESTAMP(), nullable=False),
        sa.Column("updated_at", sa.TIMESTAMP(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        schema="crypto",
    )
    op.create_index(
        "ix_bid_ask_sum_created_at",
        "bid_ask_sum",
        ["created_at"],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_bid_ask_sum_exchange_symbol_timestamp",
        "bid_ask_sum",
        ["exchange", "symbol", "timestamp"],
        unique=True,
        schema="crypto",
    )
    op.create_index(
        "ix_bid_ask_sum_time_of_minute",
        "bid_ask_sum",
        [sa.text("EXTRACT(minute from datetime)")],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_bid_ask_sum_timestamp",
        "bid_ask_sum",
        ["timestamp"],
        unique=False,
        schema="crypto",
    )
    op.create_index(
        "ix_bid_ask_sum_updated_at",
        "bid_ask_sum",
        ["updated_at"],
        unique=False,
        schema="crypto",
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "ix_bid_ask_sum_updated_at", table_name="bid_ask_sum", schema="crypto"
    )
    op.drop_index("ix_bid_ask_sum_timestamp", table_name="bid_ask_sum", schema="crypto")
    op.drop_index(
        "ix_bid_ask_sum_time_of_minute", table_name="bid_ask_sum", schema="crypto"
    )
    op.drop_index(
        "ix_bid_ask_sum_exchange_symbol_timestamp",
        table_name="bid_ask_sum",
        schema="crypto",
    )
    op.drop_index(
        "ix_bid_ask_sum_created_at", table_name="bid_ask_sum", schema="crypto"
    )
    op.drop_table("bid_ask_sum", schema="crypto")
    # ### end Alembic commands ###
